/***********************************************************************************************************************
 *
 * blueMarine Semantic - open source media workflow
 * Copyright (C) 2008-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~semantic-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.node;

import it.tidalwave.semantic.other.Repository;
import javax.annotation.Nonnull;
import java.awt.Image;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import it.tidalwave.semantic.other.Entity;
import it.tidalwave.semantic.other.Type;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: SemanticNodeManager.java,v 4fbb06e9364c 2011/03/06 21:25:16 fabrizio $
 *
 ******************************************************************************/
public interface SemanticNodeManager
  {
    public final class Locator
      {
        private Locator()
          {
          }

        /***********************************************************************
         *
         * Gets a reference to the CatalogNodeManager.
         *
         **********************************************************************/
        @Nonnull
        public static final SemanticNodeManager findSemanticNodeManager()
          {
            final Lookup lookup = Lookup.getDefault();
            final SemanticNodeManager semanticNodeManager = lookup.lookup(SemanticNodeManager.class);

            if (semanticNodeManager == null)
              {
                throw new RuntimeException("Cannot lookup SemanticNodeManager");
              }

            return semanticNodeManager;
          }
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    public Node findRootNodes (@Nonnull final Repository context);
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    public Node createEntityContainerNode (@Nonnull Type type);
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    public Image findIcon (@Nonnull Type type);
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    public Image findIcon (@Nonnull Entity entity);
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    public String findDisplayName (@Nonnull Entity entity);
  }
