/***********************************************************************************************************************
 *
 * blueMarine Semantic - open source media workflow
 * Copyright (C) 2008-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~semantic-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.node.dnd;

import javax.annotation.Nonnull;
import java.util.List;
import java.util.logging.Logger;
import java.io.IOException;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import org.openide.util.datatransfer.PasteType;
import org.openide.loaders.DataObject;
import it.tidalwave.semantic.other.Entity;
import it.tidalwave.netbeans.draganddrop.DataObjectTransferable;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: PasteTypeFactory.java,v 4fbb06e9364c 2011/03/06 21:25:16 fabrizio $
 *
 ******************************************************************************/
public class PasteTypeFactory 
  {
    private static final String CLASS = PasteTypeFactory.class.getName();
    private static final Logger logger = Logger.getLogger(CLASS);
    
    private static final DataFlavor DATA_OBJECT_FLAVOR = DataObjectTransferable.DATA_OBJECT_FLAVOR;

    @Nonnull
    private final Entity entity;
    
    public PasteTypeFactory (@Nonnull final Entity entity)
      {
        this.entity = entity;
      }
    
    public void createPasteTypes (@Nonnull final Transferable transferable,
                                  @Nonnull final List<PasteType> pasteTypes)
      {
        logger.finest("createPasteTypes(" + transferable + ", " + pasteTypes + ")");
        
//        if (transferable.getTransferDataFlavors() != null)
//          {
//            logger.finer(">>>> supported flavors: " + Arrays.asList(transferable.getTransferDataFlavors()));
//          }   
        
        if (transferable.isDataFlavorSupported(DATA_OBJECT_FLAVOR))
          {
            try 
              {
                pasteTypes.add(new AddEntityPasteType(entity, (DataObject)transferable.getTransferData(DATA_OBJECT_FLAVOR)));
              } 
            catch (IOException e) 
              {
                logger.throwing(CLASS, "createPasteTypes()", e);
              } 
            catch (UnsupportedFlavorException e) 
              {
                logger.throwing(CLASS, "createPasteTypes()", e);
              }
          }
      }
  }
