/***********************************************************************************************************************
 *
 * blueMarine Semantic - open source media workflow
 * Copyright (C) 2008-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~semantic-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.node.impl;

import javax.annotation.Nonnull;
import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.io.IOException;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import it.tidalwave.semantic.other.Type;
import it.tidalwave.openide.nodemanager.NodeDelegateFactory;

/*******************************************************************************
 *
 * A Node subclass for representing a Type.
 *
 * @author  Fabrizio Giudici
 * @version $Id: TypeNode.java,v 4fbb06e9364c 2011/03/06 21:25:16 fabrizio $
 *
 ******************************************************************************/
public class TypeNode extends SemanticNode
  {
    /** The bound Type. */
    private final Type type;
    
    protected final TypeChildFactory typeChildFactory;

    /***************************************************************************
     *
     *
     **************************************************************************/
    protected static class TypeChildFactory extends ChildFactory<Type>
      {
        private final Type type;
        
        public TypeChildFactory (final Type type)
          {
            this.type = type;
          }
        
        @Override
        @Nonnull
        protected final Node createNodeForKey (final Type type)
          {
            final NodeDelegateFactory nodeFactory = type.getLookup().lookup(NodeDelegateFactory.class);
            assert nodeFactory != null : "No NodeDelegateFactory for " + type;
            return nodeFactory.findOrCreateNodeDelegate();
          }
        
        protected final boolean createKeys (final List<Type> keys)
          {
            keys.addAll(findTypes());
            return true;
          }
        
        protected Set<Type> findTypes()
          {
            final Set<Type> types = Collections.emptySet(); //FIXME new ArrayList<Type>(type.findAllChildCategories());
//            final Collator collator = Collator.getInstance();
//            Collections.sort(types, new Comparator<Type>()
//              {
//                public int compare (final Type c1, final Type c2)
//                  {
//                    return collator.compare(c1.getDisplayName(), c2.getDisplayName());
//                  }
//              });
//
            return types;
          }
        
        public final void refresh()
          {
            refresh(false);    
          }
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    protected TypeNode (final Type type)
      {
        this(type, new TypeChildFactory(type));
      }

    /***************************************************************************
     *
     * Creates a new instance bound to a category.
     *
     * @param  category  the category
     *
     **************************************************************************/
    private TypeNode (final Type type, final TypeChildFactory typeNodeFactory)
      {
        super(Children.create(typeNodeFactory, true), type);
        this.type = type;
        this.typeChildFactory = typeNodeFactory;
      }

    /***************************************************************************
     *
     * Creates a new instance bound to a category.
     *
     * @param  category  the category
     *
     **************************************************************************/
    protected TypeNode (final TypeChildFactory typeChildFactory)
      {
        super(Children.create(typeChildFactory, true));
        this.type = null;
        this.typeChildFactory = typeChildFactory;
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public void destroy() 
      throws IOException
      {
        // release listeners
        super.destroy();
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    @Nonnull
    public String getDisplayName()
      {
        return findDisplayName(type);
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    @Nonnull
    public String getName()
      {
        return findDisplayName(type);
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Nonnull
    private String findDisplayName (@Nonnull final Type type)
      {
        return type.getDisplayName();
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public String toString()
      {
        return "TypeNode[" + type + "]";
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    public final void refreshChildren()
      {
        typeChildFactory.refresh();
      }
  }
